<?php

namespace Drupal\rate_us\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Configure settings for the Rate Us module.
 */
class RateUsConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'rate_us_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'rate_us.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('rate_us.settings');

    $node_types = NodeType::loadMultiple();
    $node_type_options = [];
    foreach ($node_types as $type) {
      if ($type instanceof NodeType) {
        $node_type_options[$type->id()] = $type->label();
      }
    }

    $form['enabled_node_types'] = [
      '#type' => 'checkboxes',
      '#title' => t('Select Node types to enable Rate Us'),
      '#description' => t('Select which node types will have the Rate Us form enabled.'),
      '#options' => $node_type_options,
      '#default_value' => $config->get('enabled_node_types') ?: [],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('rate_us.settings')
      ->set('enabled_node_types', $form_state->getValue('enabled_node_types'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
